@@ -6,7 +6,6 @@
 
 anova.manyglm <- function(object, ..., resamp="residual", test="LR", p.uni="none", nBoot=1000, cor.type=object$cor.type, ld.perm=FALSE, filename=NULL ) 
 {
-    tol = object$tol
     if (cor.type!="I" & test=="LR") {
         warning("The likelihood ratio test can only be used if correlation matrix of the abundances is is assumed to be the Identity matrix. The Wald Test will be used.")
         test <- "wald"
@@ -17,15 +16,36 @@ anova.manyglm <- function(object, ..., resamp="residual", test="LR", p.uni="none
 	    return(anova.manylm(object, ..., resamp=resamp, test="LR", p.uni=p.uni, nBoot=nBoot, cor.type=cor.type, shrink.param=object$shrink.param, tol=tol, ld.perm=ld.perm, filename=filename))
         else {
 	    warning("For an manylm object, only the likelihood ratio test and F test are supported. So the test option is changed to `'F''. ")
-	    return(summary.manylm(object, resamp=resamp, test="F", p.uni=p.uni, nBoot=nBoot, cor.type=cor.type, tol=tol, ld.perm=ld.perm, filename=filename, ... ))
+	    return(anova.manylm(object, resamp=resamp, test="F", p.uni=p.uni, nBoot=nBoot, cor.type=cor.type, tol=tol, ld.perm=ld.perm, filename=filename, ... ))
 	}
     }   
     else if (!any(class(object)=="manyglm"))
         stop("The function 'anova.manyglm' can only be used for a manyglm or manylm object.")
 
+    #check if any non manylm object in ...
+    objects <- list(object, ...)    
+    dots <- list(...)
+    ndots <- length(dots)
+    if (ndots>0) {
+       which <- rep(TRUE, ndots+1)
+       for (i in 1:ndots) {
+           if (!any(class(dots[[i]])=="manyglm")){
+              objectname <- names(dots[i])
+              warning(paste(objectname, "is not a manyglm object nor a valid argument- removed from input"))
+              which[i+1] <- FALSE
+           }
+       }
+       objects <- objects[which]
+    }
+
+    tol = object$tol
+    nModels = length(objects)
     nRows <- nrow(object$y)
     nVars <- ncol(object$y)
     nParam <- ncol(object$x)
+    dimnam.a <- dimnames(object$y)[[2]]
+    if (is.null(dimnam.a)) dimnam.a <- paste("abund", 1:nVars)
+
     Y <- matrix(as.integer(object$y), nrow=nRows, ncol=nVars) 
     if (is.null(Y)) {
     #      mu.eta <- object$family$mu.eta
@@ -33,12 +53,6 @@ anova.manyglm <- function(object, ..., resamp="residual", test="LR", p.uni="none
         Y <- object$fitted.values + object$residuals * log(eta)	     
      }
 
-    dimnam.a <- dimnames(object$y)[[2]]
-
-    objects <- list(object, ...)
-    tol = object$tol
-    nModels = length(objects)
-
     w <- object$weights
     if (is.null(w)) w  <- rep(1, times=nRows)
     else {
@@ -106,53 +120,36 @@ anova.manyglm <- function(object, ..., resamp="residual", test="LR", p.uni="none
     # ANOVA
     if (nModels==1) {
        # test the significance of each model terms
-       x <- model.matrix(object)
-       varseq <- attr(x, "assign")
-       nvars <- max(0, varseq)+1
-       if (nvars > 1) {
-          # get the shrinkage estimates
-          if (cor.type == "R") shrink.param <- c(rep(1,nvars))
-	  else shrink.param <- c(rep(0, nvars))
-	  if (cor.type=="shrink") shrink.param[1] <- object$shrink.param
-          tX <- matrix(1, nrow=nRows, ncol=1)
+       X <- object$x
+       varseq <- object$assign
+       nterms <- max(0, varseq)+1
+       resdev <- resdf <- NULL
+       # get the shrinkage estimates
+       if (cor.type == "R") shrink.param <- c(rep(1,nterms))
+       else shrink.param <- c(rep(0, nterms))
+       if (cor.type=="shrink") shrink.param[1] <- object$shrink.param
+       tX <- matrix(1, nrow=nRows, ncol=1)
 
-          XvarIn <- matrix(ncol=nParam, nrow=nvars, 1)  
-	  resdev <- resdf <- NULL
-          for ( i in 0L:(nvars-2)){ # exclude object itself
-             fit <- .Call("RtoGlm", modelParam, Y, x[,varseq<=i,drop=FALSE], 
+       XvarIn <- matrix(ncol=nParam, nrow=nterms, 1)  
+       for ( i in 0L:(nterms-2)){ # exclude object itself
+           fit <- .Call("RtoGlm", modelParam, Y, X[,varseq<=i,drop=FALSE], 
 	             PACKAGE="mvabund")
-
-	     XvarIn[nvars-i, varseq>i] <- 0 # in reversed order
-
-             if (cor.type=="shrink") { 
-                 shrink.param[nvars-i] <- ridgeParamEst(dat=fit$residuals, 
+           XvarIn[nterms-i, varseq>i] <- 0 # in reversed order
+           if (cor.type=="shrink") { 
+               shrink.param[nterms-i] <- ridgeParamEst(dat=fit$residuals, 
                       X=tX, only.ridge=TRUE)$ridgeParam # in reversed order
-             }
-	     resdev <- c(resdev, fit$deviance)
-             resdf <- c(resdf, nRows-dim(fit$coefficients)[1])
-	  }
-          # get the p-values
-          val <- .Call("RtoGlmAnova", modelParam, testParams, Y, object$x, 
-	               XvarIn, bootID, shrink.param, PACKAGE="mvabund")	 
+           }
+#           resdev <- c(resdev, fit$deviance)
+           resdf <- c(resdf, nRows-dim(fit$coefficients)[1])
        }
-#       else # To do: call summary
-
        resdf <- c(resdf, object$df.residual)
 #       resdev <- c(resdev, object$deviance) 
+       nModels <- nterms
 
-       # prepare for summary
-       topnote <- paste("Model:", object$family, ", Link:", "log")
-
+       ord <- nterms:1
+       topnote <- paste("Model:", deparse(object$call))
        tl <- attr(object$terms, "term.labels")
        tl <- c("Null", tl)
-       # To do: reverse order of val subjects 
-       ord <- (nvars-1):1
-       table <- data.frame(resdf, c(NA, val$dfDiff[ord]), 
-                c(NA, val$multstat[ord]), c(NA, val$Pmultstat[ord])) 
-       uni.p <- matrix(ncol=nVars,nrow=nvars) 
-       uni.test <- matrix(ncol=nVars, nrow=nvars)
-       uni.p[2:nvars, ] <- val$Pstatj[ord,]
-       uni.test[2:nvars, ] <- val$statj[ord,]
     }   
     else {
         resdf   <- as.numeric(sapply(objects, function(x) x$df.residual))
@@ -203,26 +200,25 @@ anova.manyglm <- function(object, ..., resamp="residual", test="LR", p.uni="none
         XvarIn <- matrix(ncol=nParam, nrow=nModels, as.integer(0))  
         Xnames <- list()   # formula of each model
         for ( i in 1:nModels ) XvarIn[i, 1:ind[i, 1]] <- as.integer(1) 
-        #XvarIn <- matrix(as.integer(XvarIn), nrow=nModels, ncol=nParam)
-
-        ######## call resampTest Rcpp #########
-        val <- .Call("RtoGlmAnova", modelParam, testParams, Y, X, 
-	        XvarIn, bootID, shrink.param, PACKAGE="mvabund")
-
-	# prepare for summary
-        table <- data.frame(resdf[ord], c(NA, val$dfDiff), 
-                 c(NA, val$multstat), c(NA, val$Pmultstat)) 
-        uni.p <- matrix(ncol=nVars,nrow=nModels) 
-        uni.test <- matrix(ncol=nVars, nrow=nModels)
-        uni.p[2:nModels, ] <- val$Pstatj
-        uni.test[2:nModels, ] <- val$statj
 
         Xnames <- lapply(objects, function(x) paste(deparse(formula(x), 
                          width.cutoff=500), collapse = "\n")) 
         topnote <- paste("Model ", format(1:nModels), ": ", 
-                         Xnames, sep = "", collapse = "\n")
+                     Xnames, sep = "", collapse = "\n")
         tl <- paste("Model", 1:nModels)				 
-     } 
+     }
+
+    ######## call resampTest Rcpp #########
+    val <- .Call("RtoGlmAnova", modelParam, testParams, Y, X, 
+                 XvarIn, bootID, shrink.param, PACKAGE="mvabund")
+
+    # prepare output summary
+    table <- data.frame(resdf[ord], c(NA, val$dfDiff), 
+                 c(NA, val$multstat), c(NA, val$Pmultstat)) 
+    uni.p <- matrix(ncol=nVars,nrow=nModels) 
+    uni.test <- matrix(ncol=nVars, nrow=nModels)
+    uni.p[2:nModels, ] <- val$Pstatj
+    uni.test[2:nModels, ] <- val$statj
 
     anova <- list()
     # Supplied arguments
@@ -258,7 +254,6 @@ anova.manyglm <- function(object, ..., resamp="residual", test="LR", p.uni="none
    
     # make several univariate tables 
     attr(anova$uni.test, "title") <- attr(anova$uni.p, "title") <- "\nThe univariate Tests:\n"
-    if (is.null(dimnam.a)) dimnam.a <- paste("abund", 1:nVars)
     dimnames(anova$uni.p) <- dimnames(anova$uni.test) <- list(tl, dimnam.a)
 
     class(anova) <- "anova.manyglm"
